@@ -1,5 +1,5 @@
 # Tweepy
-# Copyright 2009-2021 Joshua Roesslein
+# Copyright 2009-2022 Joshua Roesslein
 # See LICENSE for details.
 
 from email.utils import parsedate_to_datetime
@@ -13,12 +13,8 @@ class Model:
         self._api = api
 
     def __getstate__(self):
-        # pickle
-        pickle = dict(self.__dict__)
-        try:
-            del pickle['_api']  # do not pickle the API reference
-        except KeyError:
-            pass
+        pickle = self.__dict__.copy()
+        pickle.pop('_api', None)
         return pickle
 
     @classmethod
@@ -190,37 +186,31 @@ class List(Model):
         return results
 
     def update(self, **kwargs):
-        return self._api.update_list(self.slug, **kwargs)
+        return self._api.update_list(list_id=self.id, **kwargs)
 
     def destroy(self):
-        return self._api.destroy_list(self.slug)
+        return self._api.destroy_list(list_id=self.id)
 
     def timeline(self, **kwargs):
-        return self._api.list_timeline(
-            self.user.screen_name, self.slug, **kwargs
-        )
+        return self._api.list_timeline(list_id=self.id, **kwargs)
 
     def add_member(self, id):
-        return self._api.add_list_member(self.slug, id)
+        return self._api.add_list_member(list_id=self.id, user_id=id)
 
     def remove_member(self, id):
-        return self._api.remove_list_member(self.slug, id)
+        return self._api.remove_list_member(list_id=self.id, user_id=id)
 
     def members(self, **kwargs):
-        return self._api.get_list_members(
-            self.user.screen_name, self.slug, **kwargs
-        )
+        return self._api.get_list_members(list_id=self.id, **kwargs)
 
     def subscribe(self):
-        return self._api.subscribe_list(self.user.screen_name, self.slug)
+        return self._api.subscribe_list(list_id=self.id)
 
     def unsubscribe(self):
-        return self._api.unsubscribe_list(self.user.screen_name, self.slug)
+        return self._api.unsubscribe_list(list_id=self.id)
 
     def subscribers(self, **kwargs):
-        return self._api.get_list_subscribers(
-            self.user.screen_name, self.slug, **kwargs
-        )
+        return self._api.get_list_subscribers(list_id=self.id, **kwargs)
 
 
 class Media(Model):
